@@ -1,13 +1,11 @@
 
 # Copyright 2014 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
-
-
-
-import tests
-
+import os
+import sysconfig
 import warnings
 
+import tests
 import zim.datetimetz as datetime
 
 
@@ -43,12 +41,26 @@ class TestDateTimeZ(tests.TestCase):
 		s = datetime.strftime('%%', dt)
 		self.assertEqual(s, '%')
 
-		# Failed under msys python3.7.2
-		#s = datetime.strftime('%u', dt)
-		#self.assertTrue(isinstance(s, str) and len(s) > 0)
+		# is not mingw? https://github.com/msys2/msys2.github.io/blob/source/web/docs/python.md?plain=1#L12
+		if not (os.name == 'nt' and sysconfig.get_platform().startswith('mingw')):
+			# Failed under msys python3.7.2
+			s = datetime.strftime('%u', dt)
+			self.assertTrue(isinstance(s, str) and len(s) > 0)
 
-		#s = datetime.strftime('%V', dt)
-		#self.assertTrue(isinstance(s, str) and len(s) > 0)
+			s = datetime.strftime('%V', dt)
+			self.assertTrue(isinstance(s, str) and len(s) > 0)
+
+		s = datetime.strftime('%Y 道', dt)
+		self.assertTrue(isinstance(s, str) and len(s) == 4 + 1 + 1)
+
+		s = datetime.strftime('%Y ❗', dt)
+		self.assertTrue(isinstance(s, str) and len(s) == 4 + 1 + 1)
+
+		s = datetime.strftime('%Y 👨‍👩‍👧‍👦', dt)
+		self.assertTrue(isinstance(s, str) and len(s) >= 4 + 1 + 1)
+
+		s = datetime.strftime('%Y ƑÊẶṜ', dt)
+		self.assertTrue(isinstance(s, str) and len(s) >= 4 + 1 + 4)
 
 		# strfcal
 		s = datetime.strfcal('%w', dt)
@@ -74,50 +86,3 @@ class TestDateTimeZ(tests.TestCase):
 		self.assertTrue(isinstance(start, datetime.date))
 		self.assertTrue(isinstance(end, datetime.date))
 		self.assertTrue(start <= dt.date() and end >= dt.date())
-
-
-from zim.plugins.tasklist.dates import *
-
-class TestDateParsing(tests.TestCase):
-
-	def testParsing(self):
-		date = datetime.date(2017, 3, 27)
-		for text in (
-			'2017-03-27', '2017-03',
-			'2017-W13', '2017-W13-1',
-			'2017W13', '2017W13-1',
-			'2017w13', '2017w13-1',
-			'W1713', 'W1713-1', 'W1713.1',
-			'Wk1713', 'Wk1713-1', 'Wk1713.1',
-			'wk1713', 'wk1713-1', 'wk1713.1',
-		):
-			m = date_re.match(text)
-			self.assertIsNotNone(m, 'Failed to match: %s' % text)
-			self.assertEqual(m.group(0), text)
-			obj = parse_date(m.group(0))
-			self.assertIsInstance(obj, (Day, Week, Month))
-			self.assertTrue(obj.first_day <= date <= obj.last_day)
-
-		for text in (
-			'foo', '123foo', '2017-03-270',
-			'20170317', '17-03-27', '17-03'
-			'17W', '2017W131', '2017-W131'
-		):
-			m = date_re.match(text)
-			if m:
-				print('>>', m.group(0))
-			self.assertIsNone(m, 'Did unexpectedly match: %s' % text)
-
-	def testWeekNumber(self):
-		self.assertEqual(
-			Day(2017, 3, 27),
-			Day.new_from_weeknumber(2017, 13, 1)
-		)
-		self.assertEqual(
-			Day(2017, 3, 27).weekformat(),
-			('2017-W13-1')
-		)
-		self.assertEqual(
-			Day.new_from_weeknumber(2017, 13, 7),
-			Day.new_from_weeknumber(2017, 14, 0)
-		)
