@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 
 # Copyright 2010 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 
-from __future__ import with_statement
+
 
 import tests
 
@@ -35,7 +34,7 @@ Some description
 here
 '''
 		self.assertEqual(str(StubError(6)), wanted)
-		self.assertEqual(unicode(StubError(6)), wanted)
+		self.assertEqual(str(StubError(6)), wanted)
 		self.assertEqual(repr(StubError(6)), '<StubError: Error 6>')
 
 
@@ -97,7 +96,7 @@ class TestExceptionHandler(tests.TestCase):
 
 		## Handle unexpected error or bug
 		try:
-			raise AssertionError, 'My AssertionError'
+			raise AssertionError('My AssertionError')
 		except:
 			myfilter = CatchAllLogging()
 			with myfilter:
@@ -106,7 +105,7 @@ class TestExceptionHandler(tests.TestCase):
 
 			# Should log one error message with traceback
 			self.assertEqual(len(records), 1)
-			self.assertEqual(records[0].getMessage(), 'Test Error')
+			self.assertEqual(records[0].getMessage(), _('Test Error'))
 			self.assertEqual(records[0].levelno, logging.ERROR)
 			self.assertIsNotNone(records[0].exc_info)
 		else:
@@ -115,8 +114,8 @@ class TestExceptionHandler(tests.TestCase):
 
 		## Show caught bug
 		try:
-			raise AssertionError, 'My AssertionError'
-		except Exception, error:
+			raise AssertionError('My AssertionError')
+		except Exception as error:
 			myfilter = CatchAllLogging()
 			with myfilter:
 				zim.errors.show_error(error)
@@ -124,7 +123,7 @@ class TestExceptionHandler(tests.TestCase):
 
 			# Should log one error message with traceback
 			self.assertEqual(len(records), 1)
-			self.assertEqual(records[0].getMessage(), 'Looks like you found a bug')
+			self.assertEqual(records[0].getMessage(), _('Looks like you found a bug'))
 			self.assertEqual(records[0].levelno, logging.ERROR)
 			self.assertIsNotNone(records[0].exc_info)
 		else:
