@@ -5,6 +5,7 @@ import tests
 
 from zim.search import *
 from zim.notebook import Path
+from zim.plugins import indexed_fts
 
 class TestSearchRegex(tests.TestCase):
 
@@ -23,7 +24,7 @@ class TestSearchRegex(tests.TestCase):
 			#print '>>', word, regex
 			self.assertEqual(regex_func(word).pattern, re.compile(regex, re.I | re.U).pattern)
 
-		self.assertIn(regex_func('汉字').pattern, ('汉字', '\汉\字'))
+		self.assertIn(regex_func('汉字').pattern, ('汉字', r'\汉\字'))
 			# re.escape add extra "\" prior to python3.7, but not later
 			# goal of this check is to see no "\b" surrounding chines characters
 
@@ -245,6 +246,20 @@ class TestSearchFiles(TestSearch):
 		'''Test search API with file based notebook'''
 		TestSearch.runTest(self)
 
+@tests.skipIf(
+	indexed_fts.IndexedFTSPlugin.check_dependencies()[0] == False,
+	"Indexed FTS plugin not available"
+)
+class TestSearchIndexed(TestSearch):
+	'''Test case for integration with the indexed_fts plugin'''
+
+	def setUp(self):
+		plugin = PluginManager.load_plugin('indexed_fts')
+		TestSearch.setUp(self)
+
+	def runTest(self):
+		TestSearch.runTest(self)
+
 
 class TestUnicode(tests.TestCase):
 
