@@ -1,5 +1,5 @@
 
-# Copyright 2015 Jaap Karssenberg <jaap.karssenberg@gmail.com>
+# Copyright 2015,2023 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 
 
@@ -13,6 +13,15 @@ try:
 except:
 	gtkspell = None
 
+
+try:
+	import gi
+	gi.require_version('Gspell', '1')
+	from gi.repository import Gspell
+except:
+	Gspell = None
+
+
 try:
 	import gtkspellcheck
 except:
@@ -33,11 +42,12 @@ class TestSpell(object):
 	def setUp(self):
 		self._restore = (
 			zim.plugins.spell.gtkspell,
+			zim.plugins.spell.Gspell,
 			zim.plugins.spell.gtkspellcheck
 		)
 
 	def tearDown(self):
-		zim.plugins.spell.gtkspell, zim.plugins.spell.gtkspellcheck = \
+		zim.plugins.spell.gtkspell, zim.plugins.spell.Gspell, zim.plugins.spell.gtkspellcheck = \
 			self._restore
 
 	def runTest(self, adapterclass):
@@ -69,15 +79,27 @@ class TestGtkspell(TestSpell, tests.TestCase):
 
 	def runTest(self):
 		zim.plugins.spell.gtkspell = gtkspell
+		zim.plugins.spell.Gspell = None
 		zim.plugins.spell.gtkspellcheck = None
 		TestSpell.runTest(self, zim.plugins.spell.GtkspellAdapter)
 
 
+@tests.skipIf(Gspell is None, 'Gspell not installed')
+class TestGspell(TestSpell, tests.TestCase):
+
+	def runTest(self):
+		zim.plugins.spell.Gspell = Gspell
+		zim.plugins.spell.gtkspell = None
+		zim.plugins.spell.gtkspellcheck = None
+		TestSpell.runTest(self, zim.plugins.spell.GspellAdapter)
+
+
 @tests.skipIf(gtkspellcheck is None, 'gtkspellcheck not installed')
 class TestGtkspellchecker(TestSpell, tests.TestCase):
 
 	def runTest(self):
 		zim.plugins.spell.gtkspell = None
+		zim.plugins.spell.Gspell = None
 		zim.plugins.spell.gtkspellcheck = gtkspellcheck
 		TestSpell.runTest(self, zim.plugins.spell.GtkspellcheckAdapter)
 
@@ -102,13 +124,13 @@ class TestReplaceWordWithFormatting(TextBufferTestCaseMixin, tests.TestCase):
 		new_word = "misspelled"
 		start, end = buffer.get_iter_at_offset(0), buffer.get_iter_at_offset(8)
 		self.replace_word(buffer, start, end, new_word)
-		self.assertBufferEquals(buffer,
+		self.assertBufferEqual(buffer,
 			'<strong>misspelled</strong>\n'
 			'<emphasis>here misplled here as well</emphasis>\n\n'
 		)
 		start, end = buffer.get_iter_at_offset(16), buffer.get_iter_at_offset(24)
 		self.replace_word(buffer, start, end, new_word)
-		self.assertBufferEquals(buffer,
+		self.assertBufferEqual(buffer,
 			'<strong>misspelled</strong>\n'
 			'<emphasis>here misspelled here as well</emphasis>\n\n'
 		)
