@@ -35,15 +35,6 @@ class EmptyWindowObject(object):
 		return None
 
 
-class MockNavigation(object):
-
-	def __init__(self):
-		self.opened = None
-
-	def open_page(self, page):
-		self.opened = page
-
-
 class TestUIActions(tests.TestCase):
 
 	def setUp(self):
@@ -55,7 +46,7 @@ class TestUIActions(tests.TestCase):
 			}
 		)
 		self.page = self.notebook.get_page(Path('Test'))
-		self.navigation = MockNavigation()
+		self.navigation = tests.MockObject(methods=('open_page', 'open_notebook', 'open_manual'))
 		self.uiactions = UIActions(
 			window,
 			self.notebook,
@@ -75,7 +66,7 @@ class TestUIActions(tests.TestCase):
 			self.uiactions.new_page()
 
 		self.assertTrue(page.exists())
-		self.assertEqual(self.navigation.opened, page)
+		self.assertEqual(self.navigation.lastMethodCall, ('open_page', page))
 
 	def testCreateNewPageFailsForExistingPage(self):
 		from zim.notebook import PageExistsError
@@ -125,7 +116,7 @@ class TestUIActions(tests.TestCase):
 				self.uiactions.new_page()
 
 			self.assertTrue(page.exists())
-			self.assertEqual(self.navigation.opened, page)
+			self.assertEqual(self.navigation.lastMethodCall, ('open_page', page))
 
 	def testCreateNewChildPage(self):
 		page = self.notebook.get_page(Path('Test:Child'))
@@ -139,7 +130,7 @@ class TestUIActions(tests.TestCase):
 			self.uiactions.new_sub_page()
 
 		self.assertTrue(page.exists())
-		self.assertEqual(self.navigation.opened, page)
+		self.assertEqual(self.navigation.lastMethodCall, ('open_page', page))
 
 	def testOpenAnotherNotebook(self):
 		from zim.gui.notebookdialog import NotebookDialog
@@ -253,8 +244,9 @@ class TestUIActions(tests.TestCase):
 			dialog.set_input(name='ExistingPage')
 			self.assertRaises(PageExistsError, dialog.do_response_ok)
 
-		with tests.DialogContext(renamepage):
-			self.uiactions.move_page()
+		with tests.LoggingFilter('zim', 'Page already exists'):
+			with tests.DialogContext(renamepage):
+				self.uiactions.move_page()
 
 	def testRenamePageNonExistingPageFails(self):
 		from zim.notebook import PageNotFoundError
@@ -264,8 +256,9 @@ class TestUIActions(tests.TestCase):
 			dialog.set_input(name='NewName')
 			self.assertRaises(PageNotFoundError, dialog.do_response_ok)
 
-		with tests.DialogContext(renamepage):
-			self.uiactions.move_page(page)
+		with tests.LoggingFilter('zim', 'No such page'):
+			with tests.DialogContext(renamepage):
+				self.uiactions.move_page(page)
 
 	def testRenamePageWithPageUpdateHeading(self):
 		page = self.notebook.get_page(Path('MyPage'))
@@ -427,8 +420,9 @@ class TestUIActions(tests.TestCase):
 			dialog.set_input(parent=':')
 			self.assertRaises(PageExistsError, dialog.do_response_ok)
 
-		with tests.DialogContext(movepage):
-			self.uiactions.move_page(page)
+		with tests.LoggingFilter('zim', 'Page already exists'):
+			with tests.DialogContext(movepage):
+				self.uiactions.move_page(page)
 
 	def testMovePageFailsForExistingTextFile(self):
 		from zim.notebook import PageNotAvailableError
@@ -443,8 +437,9 @@ class TestUIActions(tests.TestCase):
 			dialog.set_input(parent=':')
 			self.assertRaises(PageNotAvailableError, dialog.do_response_ok)
 
-		with tests.DialogContext(movepage):
-			self.uiactions.move_page(page)
+		with tests.LoggingFilter('zim', 'Page not available'):
+			with tests.DialogContext(movepage):
+				self.uiactions.move_page(page)
 
 	def testMovePageNonExistingPageFails(self):
 		from zim.notebook import PageNotFoundError
@@ -454,8 +449,9 @@ class TestUIActions(tests.TestCase):
 			dialog.set_input(parent='NewParent')
 			self.assertRaises(PageNotFoundError, dialog.do_response_ok)
 
-		with tests.DialogContext(movepage):
-			self.uiactions.move_page(page)
+		with tests.LoggingFilter('zim', 'No such page'):
+			with tests.DialogContext(movepage):
+				self.uiactions.move_page(page)
 
 	def testMovePageUpdateLinks(self):
 		referrer = self.notebook.get_page(Path('Referrer'))
@@ -610,6 +606,7 @@ class TestUIActions(tests.TestCase):
 		with tests.DialogContext(check_backlinks):
 			self.uiactions.show_search_backlinks()
 
+	@tests.expectedFailureIf(os.name == 'nt') # Fails at random in automated tests
 	def testShowRecentChangesDialog(self):
 
 		def use_recent_changes(dialog):
@@ -635,19 +632,21 @@ class TestUIActions(tests.TestCase):
 		with tests.DialogContext(use_recent_changes):
 			self.uiactions.show_recent_changes()
 
-		# self.assertEqual(self.navigation.opened, Path('NewPage')) # FIXME: fails at random in automated tests
+		self.assertEqual(self.navigation.lastMethodCall, ('open_page', Path('NewPage')))
 
 	def testShowServerDialog(self):
-		from zim.main import ZIM_APPLICATION
-		ZIM_APPLICATION._running = True # HACK
+		application = tests.MockObject(methods=('add_window',))
+		window = tests.MockObject(return_values={'get_application': application})
+		self.uiactions.widget = tests.MockObject(return_values={'get_toplevel': window})
 
 		from zim.gui.server import ServerWindow
 		ServerWindow.show_all = tests.CallBackLogger()
-		ServerWindow.present = tests.CallBackLogger()
 
 		self.uiactions.show_server_gui()
 
-		self.assertTrue(ServerWindow.present.hasBeenCalled)
+		self.assertTrue(ServerWindow.show_all.hasBeenCalled)
+		self.assertEqual(application.lastMethodCall[0], 'add_window')
+		self.assertIsInstance(application.lastMethodCall[1], ServerWindow)
 
 	def testReloadIndex(self):
 		self.uiactions.check_and_update_index()
@@ -677,27 +676,15 @@ class TestUIActions(tests.TestCase):
 		# more tests in tests/customtools.py
 
 	def testOpenHelp(self, page=None):
-		from zim.main import ZIM_APPLICATION
-		ZIM_APPLICATION._running = True # HACK
+		self.uiactions.show_help()
+		self.assertEqual(self.navigation.lastMethodCall, ('open_manual', None))
 
-		def check_window(window):
-			self.assertEqual(window.notebook.folder.basename, 'manual')
-			if page:
-				self.assertEqual(window.page, page)
-
-		with tests.LoggingFilter('zim', 'Exception while loading plugin:'):
-			with tests.WindowContext(check_window, check_window): # window.present() called twice
-				self.uiactions.show_help()
-
-	@tests.expectedFailure  # page opened after window.present
 	def testOpenHelpFAQ(self):
 		self.testOpenHelp(page='FAQ')
 
-	@tests.expectedFailure  # page opened after window.present
 	def testOpenHelpKeys(self):
 		self.testOpenHelp(page='Help:Key Bindings')
 
-	@tests.expectedFailure  # page opened after window.present
 	def testOpenHelpBugs(self):
 		self.testOpenHelp(page='Bugs')
 
@@ -748,7 +735,7 @@ class TestUIActionsRealFile(tests.TestCase):
 			content={'Test': 'Test 123'}
 		)
 		self.page = self.notebook.get_page(Path('Test'))
-		self.navigation = MockNavigation()
+		self.navigation = tests.MockObject(methods=('open_page', 'open_notebook'))
 		self.uiactions = UIActions(
 			window,
 			self.notebook,
@@ -792,8 +779,9 @@ class TestUIActionsRealFile(tests.TestCase):
 		def question_yes(dialog):
 			dialog.answer_yes()
 
-		with tests.DialogContext(fail_trash, question_yes, DeletePageDialog):
-			self.uiactions.delete_page()
+		with tests.LoggingFilter('zim', 'Test'):
+			with tests.DialogContext(fail_trash, question_yes, DeletePageDialog):
+				self.uiactions.delete_page()
 
 		self.assertFalse(self.page.exists())
 
@@ -808,13 +796,14 @@ class TestUIActionsRealFile(tests.TestCase):
 
 		def fail_trash(dialog):
 			assert isinstance(dialog, TrashPageDialog)
-			dialog.do_response_ok() # NOT assert_repsonse_ok - we want to fail
+			dialog.do_response_ok() # NOT assert_response_ok - we want to fail
 
 		def question_no(dialog):
 			dialog.answer_no()
 
-		with tests.DialogContext(fail_trash, question_no):
-			self.uiactions.delete_page()
+		with tests.LoggingFilter('zim', 'Test'):
+			with tests.DialogContext(fail_trash, question_no):
+				self.uiactions.delete_page()
 
 		self.assertTrue(self.page.exists())
 
@@ -972,6 +961,7 @@ class TestUIActionsRealFile(tests.TestCase):
 				with tests.DialogContext(ErrorDialog):
 					self.uiactions.open_document_root()
 
+	@tests.expectedFailureIf(os.name == 'nt') # Fails at random in automated tests
 	def testEditPageSource(self):
 		from zim.gui.widgets import MessageDialog
 		from zim.newfs import LocalFile
