@@ -21,6 +21,14 @@ if USED_PYTHON_VERSION < REQUIRED_MINIMUM_PYTHON_VERSION:
 
 
 def init_environment(installdir):
+	# Automatically set data dir for a virtualenv install
+	if sys.prefix != sys.base_prefix:
+		zim_data_dir = os.path.join(sys.prefix, 'share')
+		if os.path.isdir(zim_data_dir):
+			os.environ['XDG_DATA_DIRS'] = os.pathsep.join(
+					[zim_data_dir] + os.getenv('XDG_DATA_DIRS', '').split(os.pathsep)
+				).strip(os.pathsep)
+
 	# Try loading custom environment setup
 	env_config_file = os.path.join(installdir, 'environ.ini')
 	if os.path.exists(env_config_file):
@@ -54,22 +62,19 @@ def _parse_environment_param(value, installdir):
 
 	return os.pathsep.join(parts)
 
-
 def init_logging():
 	import logging
 
 	# Win32: must setup log file or it tries to write to $PROGRAMFILES
 	# See http://www.py2exe.org/index.cgi/StderrLog
-	# If startup is OK, this will be overruled in zim/main with per user log file
-	if os.name == "nt" and (
-		sys.argv[0].endswith('.exe')
-		or sys.executable.endswith('pythonw.exe')
-	):
-		import tempfile
-		dir = tempfile.gettempdir()
-		if not os.path.isdir(dir):
-			os.makedirs(dir)
-		err_stream = open(dir + "\\zim.exe.log", "w")
+	# Do the same for other platforms if not running from a terminal
+	py2exe = os.name == "nt" and (sys.argv[0].endswith('.exe') or sys.executable.endswith('pythonw.exe'))
+	if py2exe or not (sys.stdout.isatty() and sys.stderr.isatty()):
+		import zim
+		import zim.newfs
+		dir = zim.newfs.get_tmpdir()
+		zim.debug_log_file = os.path.join(dir.path, "zim.log")
+		err_stream = open(zim.debug_log_file, "w")
 		sys.stdout = err_stream
 		sys.stderr = err_stream
 
@@ -85,7 +90,7 @@ def init_logging():
 
 
 def init_macOS():
-	# MacOS: Set the bundle name so that the application menu shows 'Zim'
+	# macOS: Set the bundle name so that the application menu shows 'Zim'
 	# instead of 'Python' (this requires the pyobjc package)
 	try:
 		from Foundation import NSBundle
@@ -112,6 +117,7 @@ def main():
 	try:
 		import zim
 		import zim.main
+		import zim.config
 	except ImportError:
 		sys.excepthook(*sys.exc_info())
 		print('ERROR: Could not find python module files in path:', file=sys.stderr)
@@ -119,6 +125,13 @@ def main():
 		print('\nTry setting PYTHONPATH', file=sys.stderr)
 		sys.exit(1)
 
+	# Check if we can find our own data files
+	_file = zim.config.data_file('zim.png')
+	if not (_file and _file.exists()): #pragma: no cover
+		print('ERROR: Could not find data files in path:', file=sys.stderr)
+		print(list(map(str, zim.config.data_dirs(include_non_existing=True))), file=sys.stderr)
+		print('\nTry setting XDG_DATA_DIRS', file=sys.stderr)
+
 	# Run the application and handle some exceptions
 	exit_code = 1
 	try:
@@ -129,6 +142,8 @@ def main():
 		print(err.msg, file=sys.stderr)
 	except KeyboardInterrupt: # e.g. <Ctrl>C while --server
 		print('Interrupt', file=sys.stderr)
+	except Exception as err:
+		print(err, file=sys.stderr)
 	finally:
 		sys.exit(exit_code)
 
