@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
 
-# Copyright 2010-2013 Jaap Karssenberg <jaap.karssenberg@gmail.com>
+# Copyright 2010-2016 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 '''Thin wrapper for 'datetime' module from the standard library.
 Provides timezone info for the local time. Based on example code
@@ -74,7 +73,7 @@ class LocalTimezone(tzinfo):
 
 
 # Initialize setting for first day of the week. This is locale
-# dependent, and the gtk.Calendar widget already has good code to find it out.
+# dependent, and the Gtk.Calendar widget already has good code to find it out.
 # Unfortunately, the widget keeps that data private *%#*$()()*) !
 
 MONDAY = 0 # iso calendar starts week at Monday
@@ -90,7 +89,10 @@ def init_first_day_of_week():
 		else:
 			FIRST_DAY_OF_WEEK = SUNDAY
 		logger.debug('According to babel first day of week is %i', FIRST_DAY_OF_WEEK)
-	except ImportError:
+	except Exception as e:
+		if not isinstance(e, ImportError):
+			logger.exception('Exception while loading \'babel\' library for first day of week')
+
 		# Fallback gleaned from gtkcalendar.c - hence the inconsistency
 		# with weekday numbers in iso calendar...
 		t = _("calendar:week_start:0")
@@ -100,7 +102,7 @@ def init_first_day_of_week():
 		elif t[-1] == '1':
 			FIRST_DAY_OF_WEEK = MONDAY
 		else:
-			logger.warn("Whoever translated 'calendar:week_start:0' did so wrongly.")
+			logger.warning("Whoever translated 'calendar:week_start:0' did so wrongly.")
 			FIRST_DAY_OF_WEEK = SUNDAY
 
 
@@ -223,44 +225,27 @@ def strfcal(format, date):
 		else:
 			return code # ignore unsupported codes
 
-	return re.sub(r'\%.', replacefunc, format)
+	return re.sub(r'%.', replacefunc, format)
 
 
 def strftime(format, date):
-	'''Extended version of strftime that adds a few POSIX codes
-
-	  - C{%u} is replaced by the weekday as a decimal number [1,7], with 1 representing Monday.
-	  - C{%V} is replaced by the week number of the year (Monday as the first day of the week)
-	    as a decimal number [01,53]. If the week containing 1 January has four or more days in
-	    the new year, then it is considered week 1. Otherwise, it is the last week of the
-	    previous year, and the next week is week 1.
-	'''
-	year, week, weekday = date.isocalendar()
-
-	def replacefunc(matchobj):
-		code = matchobj.group(0)
-		if code == '%u':
-			return str(weekday)
-		elif code == '%V':
-			return str(week)
-		else:
-			return code # ignore unsupported codes
-
-	format = re.sub(r'\%.', replacefunc, format)
-	string = date.strftime(str(format)) # str() needed for python 2.5 compatibility strftime
-	string = string.decode(locale.getlocale()[1]) # decode local specific output to unicode
-	return string
-
+	# TODO: deprecate this function
+	# see issue #2457
+	# When we pass some unicode characters (e.g. emoji)
+	# to strftime under Windows we get a UnicodeEncodeError exception.
+	# To avoid this, we convert all non-ASCII characters to their \uXXXXXX representations,
+	# then pass to the strftime function and convert back to a Unicode string.
+	return date.strftime(format.encode('unicode-escape').decode('utf-8')).encode('raw-unicode-escape').decode('unicode-escape')
 
 
 if __name__ == '__main__': #pragma: no cover
 	import gettext
-	gettext.install('zim', None, unicode=True, names=('_', 'gettext', 'ngettext'))
+	gettext.install('zim', None, names=('_', 'gettext', 'ngettext'))
 	init_first_day_of_week()
 
 	if FIRST_DAY_OF_WEEK == SUNDAY:
-		print 'First day of week: Sunday'
+		print('First day of week: Sunday')
 	else:
-		print 'First day of week: Monday'
-	print 'Now:', now().isoformat(), strftime("%z, %Z", now())
-	print 'Calendar:', strfcal('day %w of week %W %Y', now())
+		print('First day of week: Monday')
+	print('Now:', now().isoformat(), strftime("%z, %Z", now()))
+	print('Calendar:', strfcal('day %w of week %W %Y', now()))
