@@ -5,11 +5,11 @@
 
 import re
 
-import zim.parser
-from zim.parser import fix_unicode_chars, Rule
+from zim.parse import fix_unicode_whitespace
+from zim.parse.regexparser import Rule, RegexParser
 
 from zim.formats import *
-from zim.parsing import url_re
+from zim.parse.links import old_url_link_re
 
 
 info = {
@@ -38,10 +38,10 @@ class Parser(ParserClass):
 		if not isinstance(input, str):
 			input = ''.join(input)
 
-		input = fix_unicode_chars(input)
+		input = fix_unicode_whitespace(input)
 
-		parser = zim.parser.Parser(
-			Rule(LINK, url_re.r, process=self.parse_url) # FIXME need .r attribute because url_re is a Re object
+		parser = RegexParser(
+			Rule(LINK, old_url_link_re.pattern, process=self.parse_url) # FIXME need .r attribute because url_re is a Re object
 		)
 
 		builder = ParseTreeBuilder()
@@ -173,8 +173,7 @@ class Dumper(DumperClass):
 		return (bullet, ' ') + tuple(strings)
 
 	def dump_anchor(self, tag, attrib, strings=None):
-		# TODO: what should be returned here?
-		return ("[id: ", attrib['name'], "]")
+		return () # anchor has no text representation
 
 	def dump_link(self, tag, attrib, strings=None):
 		# Just plain text, either text of link, or link href
@@ -194,7 +193,7 @@ class Dumper(DumperClass):
 		text = alt if alt else src
 		return [text]
 
-	def dump_object_fallback(self, tag, attrib, strings):
+	def dump_object_fallback(self, tag, attrib, strings=None):
 		return strings
 
 	def dump_table(self, tag, attrib, strings):
