@@ -8,16 +8,12 @@ import logging
 
 logger = logging.getLogger('zim.formats.wiki')
 
-from zim.parser import Rule, fix_unicode_chars, convert_space_to_tab
-from zim.parser import Parser as RuleParser
-from zim.parsing import url_encode, URL_ENCODE_DATA, \
-	escape_string, unescape_string, split_escaped_string
-from zim.parsing import url_re as old_url_re
+from zim.parse import convert_space_to_tab, fix_unicode_whitespace
+from zim.parse.regexparser import Rule, RegexParser
+from zim.parse.links import is_url_link, match_url_link, url_link_re, old_url_link_re
 from zim.formats import *
 from zim.formats.plain import Dumper as TextDumper
-
-old_url_re = old_url_re.p
-
+from zim.parse.encode import escape_string, split_escaped_string, unescape_string, url_encode, URL_ENCODE_DATA
 
 WIKI_FORMAT_VERSION = 'zim 0.6'
 assert WIKI_FORMAT_VERSION != 'zim 0.26' # skip number for historic reasons
@@ -48,16 +44,16 @@ bullet_pattern = '(?:[\\*\u2022]|\\[[ \\*x><]\\]|\\d+\\.|[a-zA-Z]\\.)[\\ \\t]+'
 bullet_line_re = re.compile(r'^(\t*)(%s)(.*$\n?)' % bullet_pattern)
 	# matches list item: prefix, bullet, text
 
-number_bullet_re = re.compile('^(\d+|[a-zA-Z])\.$')
+number_bullet_re = re.compile(r'^(\d+|[a-zA-Z])\.$')
 
-param_re = re.compile('([\w-]+)=("(?:[^"]|"{2})*"|\S*)')
+param_re = re.compile(r'([\w-]+)=("(?:[^"]|"{2})*"|\S*)')
 	# matches parameter list for objects
 	# allow name="foo bar" and name=Foo
 
 empty_lines_re = re.compile(r'((?:^[ \t]*\n)+)', re.M | re.U)
 	# match multiple empty lines
 
-unindented_line_re = re.compile('^\S', re.M)
+unindented_line_re = re.compile(r'^\S', re.M)
 	# match any unindented line
 
 
@@ -67,103 +63,6 @@ def _remove_indent(text, indent):
 		# supported in python 2.6
 
 
-# NOTE: we follow rules of GFM spec, except:
-#  - we allow any URL scheme
-#  - we allow only one domain section (e.g. "localhost")
-#  - we add a file URI match
-#  - do not allow to start with "__" because of conflict with mark markup parsing
-# For GFM Markdown parser, remove these exceptions
-#
-# File paths cannot contain '\', '/', ':', '*', '?', '"', '<', '>', '|'
-# These are valid URL / path seperators: / \ : ? |
-# So restrict matching " < > and also '
-_url = r'''
-	(www\.|https?://|\w+://)			# autolink & autourl prefix
-	(?P<domain>([\w\-]+\.)*[\w\-]+)		# domain sections (GFM says "2 or more", so "+" instead of "*")
-	[^\s<]*								# any non-space char except "<"
-	'''
-_email = r'''
-	(mailto:)?
-	[\w\.\-_+]+@						# email prefix
-	([\w\-_]+\.)+[\w\-_]+				# email domain
-	'''
-_file = r'''
-	file:/+
-	[^\s"<>\']+
-	'''
-
-url_re = re.compile(
-	'''\\b
-	(?!__)(?P<url>%s)     |
-	(?!__)(?P<email>%s) |
-	(?P<fileuri>%s)
-	''' % (_url, _email, _file),
-	re.VERBOSE
-)
-
-url_trailing_punctuation = ('?', '!', '.', ',', ':', '*', '_', '~', "'", '"')
-	# do not add ";" here, it is handled separatedly in the function
-
-
-def is_url(text):
-	'''Matches url_re and number of closing brackets matches
-	See L{https://github.github.com/gfm/#autolinks-extension-}
-	@param text: text to match as url
-	@returns: C{True} if C{text} is a valid url according to GFM rules
-	'''
-	url = match_url(text)
-	return url == text # No trailing puntuation or ")" excluded
-
-
-def match_url(text):
-	'''Match regex and count number of closing brackets
-	See L{https://github.github.com/gfm/#autolinks-extension-}
-	@param text: text to match as url
-	@returns: the url or None
-	'''
-	m = url_re.match(text)
-	if m:
-		url = m.group(0)
-		if m.lastgroup == 'email':
-			# Do not allow end in "-" or "_", use trailing "."
-			# modified rule from GFM to allow trailing __ because of mark markup
-			while url:
-				if url[-1] == '.':
-					url = url[:-1]
-				elif url[-1] == '_' and url[-2] == '_':
-					url = url[:-2]
-				elif url[-1] in ('-', '_'):
-					return None
-				else:
-					break
-			return url or None
-
-		# continue processing regular URL or file URI
-		if m.lastgroup == 'url':
-			domain = m.group('domain').split('.')
-			if '_' in domain[-1] or (len(domain) > 1 and '_' in domain[-2]):
-				# Last two domain sections cannot contain "_"
-				return None
-	else:
-		return None
-
-	while url:
-		if url[-1] in url_trailing_punctuation \
-			or (url[-1] == ')' and url.count(')') > url.count('(')):
-				url = url[:-1]
-		elif url[-1] == ';':
-			m = re.search('&\w+;$', url)
-			if m:
-				ref = m.group(0)
-				url = url[:-len(ref)]
-			else:
-				url = url[:-1]
-		else:
-			return url
-	else:
-		return None
-
-
 class WikiParser(object):
 	# This parser uses 3 levels of rules. The top level splits up
 	# paragraphs, verbatim paragraphs, images and objects.
@@ -195,7 +94,7 @@ class WikiParser(object):
 
 	def _init_inline_parse(self):
 		# Rules for inline formatting, links and tags
-		my_url_re = old_url_re if self.backward_url_parsing else url_re
+		my_url_re = old_url_link_re if self.backward_url_parsing else url_link_re
 
 		descent = lambda *a: self.nested_inline_parser_below_link(*a)
 		self.nested_inline_parser_below_link = (
@@ -229,7 +128,7 @@ class WikiParser(object):
 		# Intermediate level, breaks up lists and indented blocks
 		# TODO: deprecate this by taking lists out of the para
 		#       and make a new para for each indented block
-		p = RuleParser(
+		p = RegexParser(
 			Rule(
 				'X-Bullet-List',
 				r'''(
@@ -266,7 +165,7 @@ class WikiParser(object):
 
 	def _init_block_parser(self):
 		# Top level parser, to break up block level items
-		p = RuleParser(
+		p = RegexParser(
 			Rule(VERBATIM_BLOCK, r'''
 				^(?P<pre_indent>\t*) \'\'\' \s*?				# 3 "'"
 				( (?:^.*\n)*? )									# multi-line text
@@ -593,7 +492,7 @@ class WikiParser(object):
 		if self.backward_url_parsing:
 			builder.append(LINK, {'href': text}, text)
 		else:
-			url = match_url(text)
+			url = match_url_link(text)
 			if url is None:
 				self.inline_parser.backup_parser_offset(len(text) - 1)
 				builder.text(text[0]) # FIXME Ideally should allow re-parsing first character
@@ -609,7 +508,7 @@ class WikiParser(object):
 
 	@staticmethod
 	def parse_anchor(builder, name, *a):
-		builder.append(ANCHOR, {'name': name}, name)
+		builder.append(ANCHOR, {'name': name})
 
 	@staticmethod
 	def parse_line(builder, text):
@@ -630,7 +529,7 @@ class Parser(ParserClass):
 			input = ''.join(input)
 
 		input = input.replace('\u2029', ' ') # Unicode PARAGRAPH SEPARATOR, causes conflict between "splitlines()" and regex "\n" matching - see issues #1760
-		input = fix_unicode_chars(input)
+		input = fix_unicode_whitespace(input)
 
 		meta, version = None, False
 		if file_input:
@@ -730,7 +629,7 @@ class Dumper(TextDumper):
 		href = attrib['href']
 
 		if not strings or href == ''.join(strings):
-			if is_url(href):
+			if is_url_link(href):
 				return (href,) # no markup needed
 			else:
 				return ('[[', href, ']]')
