@@ -285,12 +285,10 @@ class TextView(Gtk.TextView):
 
 			anchor = iter.get_child_anchor()
 			if iter.get_child_anchor():
-				widgets = anchor.get_widgets()
-				assert len(widgets) == 1, 'TODO: support multiple views of same buffer'
-				widget = widgets[0]
-				if widget.has_cursor():
-					widget.grab_cursor(position)
-					return None
+				for widget in anchor.get_widgets():
+					if widget.is_ancestor(self) and widget.has_cursor():
+						widget.grab_cursor(position)
+						return None
 
 		return Gtk.TextView.do_move_cursor(self, step_size, count, extend_selection)
 
@@ -439,6 +437,7 @@ class TextView(Gtk.TextView):
 			home, ourhome = self.get_visual_home_positions(iter)
 			if home.starts_line() and iter.compare(ourhome) < 1 \
 			and not buffer.get_iter_in_verbatim_block(iter):
+				buffer.emit('undo-save-cursor', iter)
 				row, mylist = TextBufferList.new_from_line(buffer, iter.get_line())
 				if mylist and self.preferences['recursive_indentlist']:
 					mylist.indent(row)
@@ -458,7 +457,8 @@ class TextView(Gtk.TextView):
 			iter = buffer.get_iter_at_mark(buffer.get_insert())
 			home, ourhome = self.get_visual_home_positions(iter)
 			if home.starts_line() and iter.compare(ourhome) < 1 \
-			and not buffer.get_iter_in_verbatim(iter):
+			and not buffer.get_iter_in_verbatim_block(iter):
+				buffer.emit('undo-save-cursor', iter)
 				bullet = buffer.get_bullet_at_iter(home)
 				indent = buffer.get_indent(home.get_line())
 				if keyval in KEYVALS_BACKSPACE \
