@@ -18,8 +18,8 @@ from zim.gui.applications import CustomizeOpenWithDialog, open_folder_prompt_cre
 from zim.plugins import PLUGIN_FOLDER
 from zim.config import String, ConfigManager
 from zim.plugins import PluginManager
-from zim.main import ZIM_APPLICATION
 
+from zim.gui.applications import ui_preferences as application_preferences
 from zim.gui.mainwindow import ui_preferences as interface_preferences
 from zim.gui.pageview import ui_preferences as pageview_preferences
 
@@ -47,7 +47,11 @@ def localeWarningBar(enc):
 
 class PreferencesDialog(Dialog):
 
-	def __init__(self, widget, default_tab=None, select_plugin=None):
+	def __init__(self, widget, show_tab=None, select_plugin=None):
+		'''Constructor
+		@param show_tab: tab to present in the dialog
+		@select_plugin: plugin to present in the dialog
+		'''
 		Dialog.__init__(self, widget, _('Preferences')) # T: Dialog title
 		self.preferences = ConfigManager.preferences
 		self.main_window = widget
@@ -73,7 +77,7 @@ class PreferencesDialog(Dialog):
 			# From GTK Doc: Note that due to historical reasons, GtkNotebook refuses
 			# to switch to a page unless the child widget is visible.
 			vbox.show()
-			if category == default_tab:
+			if category == show_tab:
 				gtknotebook.set_current_page(index)
 
 			fields = []
@@ -82,6 +86,7 @@ class PreferencesDialog(Dialog):
 
 			for section, preferences in (
 				('GtkInterface', interface_preferences),
+				('Application', application_preferences),
 				('PageView', pageview_preferences)
 			):
 				for p in [p for p in preferences if p[2] == category]:
@@ -118,8 +123,7 @@ class PreferencesDialog(Dialog):
 		plugins_tab_index = gtknotebook.append_page(self.plugins_tab, Gtk.Label(label=_('Plugins')))
 				# T: Heading in preferences dialog
 		self.plugins_tab.show()
-		#~ print default_tab, index
-		if default_tab == "Plugins":
+		if show_tab == "Plugins" or select_plugin is not None:
 			gtknotebook.set_current_page(plugins_tab_index)
 			if not select_plugin is None:
 					self.plugins_tab.select_plugin(select_plugin)
@@ -128,7 +132,6 @@ class PreferencesDialog(Dialog):
 		gtknotebook.append_page(ApplicationsTab(self), Gtk.Label(label=_('Applications')))
 			# T: Heading in preferences dialog
 
-
 	def _add_font_selection(self, table):
 		# need to hardcode this, cannot register it as a preference
 		table.add_inputs((
@@ -288,17 +291,27 @@ class PluginsTab(Gtk.VBox):
 		path = selected[0].get_path(selected[1])
 
 		key, active, activatable, name, klass = treeview.get_model()[path]
-
 		self._current_plugin = key
-		logger.debug('Loading description for plugin: %s', key)
+		logger.debug('[GUI/Preferences/Plugins]: Plugin[%s] is selected.', name)
+
+		if not activatable:
+			logger.debug('[GUI/Preferences/Plugins]: Plugin[%s] is not activatable, try to load it again.', name)
+			try:
+				klass = PluginManager().load_plugin(key)
+			except Exception:
+				logger.debug("[GUI/Preferences/Plugins]: Failed to load plugin[%s] again.", name)
+				activatable = False
+			else:
+				activatable = True
+				treeview.get_model()[path][2] = activatable
+				treeview.get_model()[path][4] = klass
 
 		# Insert plugin info into textview with proper formatting
 		# TODO use our own widget with formatted text here...
 		buffer = self.textbuffer
 		def insert(text, style=None):
 			if style:
-				buffer.insert_with_tags_by_name(
-					buffer.get_end_iter(), text, style)
+				buffer.insert_with_tags_by_name(buffer.get_end_iter(), text, style)
 			else:
 				buffer.insert_at_cursor(text)
 
@@ -314,7 +327,7 @@ class PluginsTab(Gtk.VBox):
 					_(
 						'This plugin cannot be enabled due to missing dependencies.\n'
 						'Please see the dependencies section below for details.\n\n'
-					),
+					), # T: help text when plugin cannot be activated
 					'red'
 				)
 			else:
@@ -323,6 +336,7 @@ class PluginsTab(Gtk.VBox):
 				# (e.g. syntax error) in the extension's Python module. Such issues
 				# are caught when the PluginsTreeModel is init'ed.
 				insert(_('There was a problem loading this plugin\n\n'), 'red')
+					# T: help text when plugin cannot be loaded due to bug / issue
 
 				if not klass:
 					self.configure_button.set_sensitive(False)
@@ -363,7 +377,8 @@ class PluginsTab(Gtk.VBox):
 		klass = self.plugins.get_plugin_class(self._current_plugin)
 		page = klass.plugin_info['help']
 		if page:
-			ZIM_APPLICATION.run('--manual', page)
+			application = self.get_toplevel().get_application()
+			application.open_manual(page)
 
 	def on_configure_button_clicked(self, button):
 		plugin = self.plugins[self._current_plugin]
@@ -468,13 +483,10 @@ class PluginConfigureDialog(Dialog):
 			# T: Heading for 'configure plugin' dialog - %s is the plugin name
 		self.vbox.add(label)
 
-		ignore = getattr(self.plugin, 'hide_preferences', [])
-		fields = [
-			field for field in
-				self.plugin.form_fields(self.plugin.plugin_preferences)
-					if field[0] not in ignore
-		]
-		self.add_form(fields, self.plugin.preferences)
+		self.add_form(
+			inputs=self.plugin.form_fields(self.plugin.plugin_preferences),
+			values=self.plugin.preferences
+		)
 
 		if plugin.plugin_notebook_properties:
 			hbox = Gtk.Box(spacing=12)
@@ -549,13 +561,15 @@ class KeyBindingsTab(Gtk.VBox):
 		self.add(ScrolledWindow(KeyBindingTreeView()))
 		self.pack_end(help_text_factory(help), False, True, 12)
 
+
 class KeyBindingTreeView(Gtk.TreeView):
 	def __init__(self):
 		GObject.GObject.__init__(self)
 		model = Gtk.ListStore(str, int, Gdk.ModifierType) # accel_path, accel_key, accel_mods
 
 		def _append(data, accel_path, accel_key, accel_mods, changed):
-			model.append((accel_path, accel_key, accel_mods))
+			if not accel_path.endswith('_menu'):
+				model.append((accel_path, accel_key, accel_mods))
 		Gtk.AccelMap.foreach(None, _append)
 
 		model.set_sort_column_id(0, Gtk.SortType.ASCENDING)
