@@ -1,5 +1,5 @@
 
-# Copyright 2008-2017 Jaap Karssenberg <jaap.karssenberg@gmail.com>
+# Copyright 2008-2020 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 
 
@@ -17,19 +17,20 @@ from functools import partial
 import zim.templates
 import zim.formats
 
-from zim.fs import File, Dir, SEP
-from zim.newfs import LocalFolder
+from zim.fs import adapt_from_oldfs
+from zim.newfs import SEP, Folder, LocalFile, LocalFolder
 from zim.config import INIConfigFile, String, ConfigDefinitionByClass, Boolean, Choice
 from zim.errors import Error
-from zim.utils import natural_sort_key
+from zim.base.naturalsort import natural_sort_key
 from zim.newfs.helpers import TrashNotSupportedError
 from zim.config import HierarchicDict
-from zim.parsing import link_type, is_win32_path_re
+from zim.parse.links import link_type, is_win32_path_re
 from zim.signals import ConnectorMixin, SignalEmitter, SIGNAL_NORMAL
 
+from .info import create_valid_interwiki_key
 from .operations import notebook_state, NOOP, SimpleAsyncOperation, ongoing_operation
-from .page import Path, Page, HRef, HREF_REL_ABSOLUTE, HREF_REL_FLOATING, HREF_REL_RELATIVE
-from .index import IndexNotFoundError, LINK_DIR_BACKWARD
+from .page import Path, Page, PageError, HRef, HREF_REL_ABSOLUTE, HREF_REL_FLOATING, HREF_REL_RELATIVE
+from .index import IndexNotFoundError, LINK_DIR_BACKWARD, ROOT_PATH
 
 DATA_FORMAT_VERSION = (0, 4)
 
@@ -40,51 +41,51 @@ class NotebookConfig(INIConfigFile):
 	# TODO - unify this call with NotebookInfo ?
 
 	def __init__(self, file):
+		file = adapt_from_oldfs(file)
 		INIConfigFile.__init__(self, file)
 		if os.name == 'nt':
 			endofline = 'dos'
 		else:
 			endofline = 'unix'
-		name = file.dir.basename if hasattr(file, 'dir') else file.parent().basename # HACK zim.fs and zim.newfs compat
+
 		self['Notebook'].define((
 			('version', String('.'.join(map(str, DATA_FORMAT_VERSION)))),
-			('name', String(name)),
+			('name', String(file.parent().basename)),
 			('interwiki', String(None)),
 			('home', ConfigDefinitionByClass(Path('Home'))),
 			('icon', String(None)), # XXX should be file, but resolves relative
 			('document_root', String(None)), # XXX should be dir, but resolves relative
+			('short_links', Boolean(False)),
 			('shared', Boolean(True)),
+			('paste_image_template', String('pasted_image_%y%m%d')),
 			('endofline', Choice(endofline, {'dos', 'unix'})),
 			('disable_trash', Boolean(False)),
+			('default_file_format', String('zim-wiki')),
+			('default_file_extension', String('.txt')),
+			('notebook_layout', String('files')),
 		))
 
 
 def _resolve_relative_config(dir, config):
 	# Some code shared between Notebook and NotebookInfo
+	dir = adapt_from_oldfs(dir)
 
 	# Resolve icon, can be relative
 	icon = config.get('icon')
 	if icon:
-		if zim.fs.isabs(icon) or not dir:
-			icon = File(icon)
-		else:
-			icon = dir.resolve_file(icon)
+		icon = LocalFile(dir.get_abspath(icon))
 
 	# Resolve document_root, can also be relative
 	document_root = config.get('document_root')
 	if document_root:
-		if zim.fs.isabs(document_root) or not dir:
-			document_root = Dir(document_root)
-		else:
-			document_root = dir.resolve_dir(document_root)
+		document_root = LocalFolder(dir.get_abspath(document_root))
 
 	return icon, document_root
 
 
 def _iswritable(dir):
 	if os.name == 'nt':
-		# Test access - (iswritable turns out to be unreliable
-		# for folders on windows..)
+		# Test access - (iswritable turns out to be unreliable for folders on windows..)
 		f = dir.file('.zim.tmp')
 		try:
 			f.write('Test')
@@ -106,14 +107,7 @@ def _cache_dir_for_dir(dir):
 	else:
 		path = 'notebook-' + dir.path.replace('/', '_').strip('_')
 
-	return XDG_CACHE_HOME.subdir(('zim', path))
-
-
-class PageError(Error):
-
-	def __init__(self, path):
-		self.path = path
-		self.msg = self._msg % path.name
+	return XDG_CACHE_HOME.folder(('zim', path))
 
 
 class PageNotFoundError(PageError):
@@ -126,14 +120,20 @@ class PageNotAllowedError(PageNotFoundError):
 			# T: description for PageNotAllowedError
 
 
-class PageExistsError(Error):
+class PageNotAvailableError(PageNotFoundError):
+	_msg = _('Page not available: %s') # T: message for PageNotAvailableError
+	description = _('This page name cannot be used due to a conflicting file in the storage')
+			# T: description for PageNotAvailableError
+
+	def __init__(self, path, file):
+		PageError.__init__(self, path)
+		self.file = file
+
+
+class PageExistsError(PageError):
 	_msg = _('Page already exists: %s') # T: message for PageExistsError
 
 
-class PageReadOnlyError(Error):
-	_msg = _('Can not modify page: %s') # T: error message for read-only pages
-
-
 class IndexNotUptodateError(Error):
 	pass # TODO description here?
 
@@ -192,10 +192,10 @@ class Notebook(ConnectorMixin, SignalEmitter):
 	@ivar name: The name of the notebook (string)
 	@ivar icon: The path for the notebook icon (if any)
 	# FIXME should be L{File} object
-	@ivar document_root: The L{Dir} object for the X{document root} (if any)
-	@ivar dir: Optional L{Dir} object for the X{notebook folder}
+	@ivar document_root: The L{Folder} object for the X{document root} (if any)
+	@ivar dir: Optional L{Folder} object for the X{notebook folder}
 	@ivar file: Optional L{File} object for the X{notebook file}
-	@ivar cache_dir: A L{Dir} object for the folder used to cache notebook state
+	@ivar cache_dir: A L{Folder} object for the folder used to cache notebook state
 	@ivar config: A L{SectionedConfigDict} for the notebook config
 	(the C{X{notebook.zim}} config file in the notebook folder)
 	@ivar index: The L{Index} object used by the notebook
@@ -225,10 +225,11 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		will return unique objects per location and keep (weak)
 		references for re-use.
 
-		@param dir: a L{Dir} object
+		@param dir: a L{Folder} object
 		@returns: a L{Notebook} object
 		'''
-		assert isinstance(dir, Dir)
+		dir = adapt_from_oldfs(dir)
+		assert isinstance(dir, LocalFolder)
 
 		nb = _NOTEBOOK_CACHE.get(dir.uri)
 		if nb:
@@ -238,17 +239,26 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		from .layout import FilesLayout
 
 		config = NotebookConfig(dir.file('notebook.zim'))
-		endofline = config['Notebook']['endofline']
-		shared = config['Notebook']['shared']
 
-		subdir = dir.subdir('.zim')
-		if not shared and subdir.exists() and _iswritable(subdir):
-			cache_dir = subdir
-		else:
+		if config['Notebook']['shared']:
 			cache_dir = _cache_dir_for_dir(dir)
+		else:
+			cache_dir = dir.folder('.zim')
+			cache_dir.touch()
+			if not (cache_dir.exists() and _iswritable(cache_dir)):
+				cache_dir = _cache_dir_for_dir(dir)
 
 		folder = LocalFolder(dir.path)
-		layout = FilesLayout(folder, endofline)
+		if config['Notebook']['notebook_layout'] == 'files':
+			layout = FilesLayout(
+				folder,
+				config['Notebook']['endofline'],
+				config['Notebook']['default_file_format'],
+				config['Notebook']['default_file_extension']
+			)
+		else:
+			raise ValueError('Unkonwn notebook layout: %s' % config['Notebook']['notebook_layout'])
+
 		cache_dir.touch() # must exist for index to work
 		index = Index(cache_dir.file('index.db').path, layout)
 
@@ -283,6 +293,7 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		self.name = None
 		self.icon = None
 		self.document_root = None
+		self.interwiki = None
 
 		if folder.watcher is None:
 			from zim.newfs.helpers import FileTreeWatcher
@@ -309,6 +320,21 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		self.connectto(self.properties, 'changed', self.on_properties_changed)
 		self.on_properties_changed(self.properties)
 
+	def __repr__(self):
+		return '<%s: %s>' % (self.__class__.__name__, self.name)
+
+	def _reload_pages_in_cache(self, path):
+		p = path.name
+		ns = path.name + ':'
+		for name, page in self._page_cache.items():
+			if name == p or name.startswith(ns):
+				if page.modified:
+					logger.error('Page with unsaved changes in cache while modifying notebook')
+				else:
+					page.reload_textbuffer()
+					# "page.haschildren" may also have changed, will be updated
+					# by signal handlers for index
+
 	@property
 	def uri(self):
 		'''Returns a file:// uri for this notebook that can be opened by zim'''
@@ -321,53 +347,13 @@ class Notebook(ConnectorMixin, SignalEmitter):
 			uri = self.uri
 		except AssertionError:
 			uri = None
-
+		from . import NotebookInfo
 		return NotebookInfo(uri, **self.config['Notebook'])
 
-	@notebook_state
-	def save_properties(self, **properties):
-		'''Save a set of properties in the notebook config
-
-		This method does an C{update()} on the dict with properties but
-		also updates the object attributes that map those properties.
-
-		@param properties: the properties to update
-		'''
-		dir = Dir(self.layout.root.path) # XXX
-
-		# Check if icon is relative
-		icon = properties.get('icon')
-		if icon and not isinstance(icon, str):
-			assert isinstance(icon, File)
-			if icon.ischild(dir):
-				properties['icon'] = './' + icon.relpath(dir)
-			else:
-				properties['icon'] = icon.user_path or icon.path
-
-		# Check document root is relative
-		root = properties.get('document_root')
-		if root and not isinstance(root, str):
-			assert isinstance(root, Dir)
-			if root.ischild(dir):
-				properties['document_root'] = './' + root.relpath(dir)
-			else:
-				properties['document_root'] = root.user_path or root.path
-
-		# Set home page as string
-		if 'home' in properties and isinstance(properties['home'], Path):
-			properties['home'] = properties['home'].name
-
-		# Actual update and signals
-		# ( write is the last action - in case update triggers a crash
-		#   we don't want to get stuck with a bad config )
-		self.properties.update(properties)
-		if hasattr(self.config, 'write'): # XXX Check needed for tests
-			self.config.write()
-
 	def on_properties_changed(self, properties):
-		dir = Dir(self.layout.root.path) # XXX
+		dir = self.layout.root
 
-		self.name = properties['name']
+		self.name = properties['name'] or self.folder.basename
 		icon, document_root = _resolve_relative_config(dir, properties)
 		if icon:
 			self.icon = icon.path # FIXME rewrite to use File object
@@ -375,6 +361,8 @@ class Notebook(ConnectorMixin, SignalEmitter):
 			self.icon = None
 		self.document_root = document_root
 
+		self.interwiki = create_valid_interwiki_key(properties['interwiki'] or self.name)
+
 	def suggest_link(self, source, word):
 		'''Suggest a link Path for 'word' or return None if no suggestion is
 		found. By default we do not do any suggestion but plugins can
@@ -404,16 +392,21 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		# As a special case, using an invalid page as the argument should
 		# return a valid page object.
 		assert isinstance(path, Path)
-		if path.name in self._page_cache \
-		and self._page_cache[path.name].valid:
+		if path.name in self._page_cache:
 			page = self._page_cache[path.name]
 			assert isinstance(page, Page)
-			page._check_source_etag()
+			page.check_source_changed()
 			return page
 		else:
 			file, folder = self.layout.map_page(path)
+			if file.exists() and not self.layout.is_source_file(file):
+				raise PageNotAvailableError(path, file)
+
 			folder = self.layout.get_attachments_folder(path)
-			page = Page(path, False, file, folder)
+			format = self.layout.get_format(file)
+			page = Page(path, False, file, folder, format)
+			if self.readonly:
+				page._readonly = True # XXX
 			try:
 				indexpath = self.pages.lookup_by_pagename(path)
 			except IndexNotFoundError:
@@ -444,33 +437,17 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		'''
 		i = 0
 		base = path.name
-		page = self.get_page(path)
-		while page.hascontent or page.haschildren:
-			i += 1
-			path = Path(base + ' %i' % i)
-			page = self.get_page(path)
-		return page
-
-	@notebook_state
-	def flush_page_cache(self, path):
-		'''Flush the cache used by L{get_page()}
-
-		After this method calling L{get_page()} for C{path} or any of
-		its children will return a fresh page object. Be aware that the
-		old Page objects may still be around but will be flagged as
-		invalid and can no longer be used in the API.
-
-		@param path: a L{Path} object
-		'''
-		names = [path.name]
-		ns = path.name + ':'
-		names.extend(k for k in list(self._page_cache.keys()) if k.startswith(ns))
-		for name in names:
-			if name in self._page_cache:
-				page = self._page_cache[name]
-				assert not page.modified, 'BUG: Flushing page with unsaved changes'
-				page.valid = False
-				del self._page_cache[name]
+		while True:
+			try:
+				page = self.get_page(path)
+			except PageNotAvailableError:
+				pass
+			else:
+				if not (page.hascontent or page.haschildren):
+					return page
+			finally:
+				i += 1
+				path = Path(base + ' %i' % i)
 
 	def get_home_page(self):
 		'''Returns a L{Page} object for the home page'''
@@ -484,18 +461,16 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		@emits: store-page before storing the page
 		@emits: stored-page on success
 		'''
-		assert page.valid, 'BUG: page object no longer valid'
 		logger.debug('Store page: %s', page)
 		self.emit('store-page', page)
 		page._store()
 		file, folder = self.layout.map_page(page)
 		self.index.update_file(file)
-		page.modified = False
+		page.set_modified(False)
 		self.emit('stored-page', page)
 
 	@notebook_state
 	def store_page_async(self, page, parsetree):
-		assert page.valid, 'BUG: page object no longer valid'
 		logger.debug('Store page in background: %s', page)
 		self.emit('store-page', page)
 		error = threading.Event()
@@ -529,7 +504,7 @@ class Notebook(ConnectorMixin, SignalEmitter):
 				# HACK: Checking modified state protects against race condition
 				# in async store. Works because pageview sets "page.modified"
 				# to a counter rather than a boolean
-				page.modified = False
+				page.set_modified(False)
 				self.emit('stored-page', page)
 
 	def wait_for_store_page_async(self):
@@ -537,35 +512,32 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		if isinstance(op, SimpleAsyncOperation):
 			op()
 
-	def move_page(self, path, newpath, update_links=True):
-		'''Move a page in the notebook
+	def move_page(self, path, newpath, update_links=True, update_heading=False):
+		'''Move and/or rename a page in the notebook
 
 		@param path: a L{Path} object for the old/current page name
 		@param newpath: a L{Path} object for the new page name
 		@param update_links: if C{True} all links B{from} and B{to} this
 		page and any of it's children will be updated to reflect the
 		new page name
+		@param update_heading: if C{True} the heading of the page will be
+		changed to the basename of the new path
 
 		The original page C{path} does not have to exist, in this case
 		only the link update will done. This is useful to update links
 		for a placeholder.
 
-		Where:
-		  - C{page} is the L{Page} object for the page being updated
-		  - C{total} is an optional parameter for the number of pages
-		    still to go - if known
-
 		@raises PageExistsError: if C{newpath} already exists
 
 		@emits: move-page before the move
 		@emits: moved-page after successfull move
 		'''
-		for p in self.move_page_iter(path, newpath, update_links):
+		for p in self.move_page_iter(path, newpath, update_links, update_heading):
 			pass
 
 	@assert_index_uptodate
 	@notebook_state
-	def move_page_iter(self, path, newpath, update_links=True):
+	def move_page_iter(self, path, newpath, update_links=True, update_heading=False):
 		'''Like L{move_page()} but yields pages that are being updated
 		if C{update_links} is C{True}
 		'''
@@ -576,23 +548,36 @@ class Notebook(ConnectorMixin, SignalEmitter):
 			n_links = self.links.n_list_links_section(path, LINK_DIR_BACKWARD)
 		except IndexNotFoundError:
 			raise PageNotFoundError(path)
-		self._move_file_and_folder(path, newpath)
-		self.flush_page_cache(path)
-		self.emit('moved-page', path, newpath)
+
+		file, folder = self.layout.map_page(path)
+		if (file.exists() or folder.exists()):
+			self._move_file_and_folder(path, newpath)
+			self._reload_pages_in_cache(path)
+			self._reload_pages_in_cache(newpath)
+			self.emit('moved-page', path, newpath)
+
+			if update_links:
+				for p in self._update_links_in_moved_page(path, newpath):
+					yield p
 
 		if update_links:
-			for p in self._update_links_in_moved_page(path, newpath):
-				yield p
-
 			for p in self._update_links_to_moved_page(path, newpath):
 				yield p
 
 			new_n_links = self.links.n_list_links_section(newpath, LINK_DIR_BACKWARD)
 			if new_n_links != n_links:
-				logger.warn('Number of links after move (%i) does not match number before move (%i)', new_n_links, n_links)
+				logger.warning('Number of links after move (%i) does not match number before move (%i)', new_n_links, n_links)
 			else:
 				logger.debug('Number of links after move does match number before move (%i)', new_n_links)
 
+		if update_heading:
+			page = self.get_page(newpath)
+			tree = page.get_parsetree()
+			if not tree is None:
+				tree.set_heading_text(newpath.basename)
+				page.set_parsetree(tree)
+				self.store_page(page)
+
 	def _move_file_and_folder(self, path, newpath):
 		file, folder = self.layout.map_page(path)
 		if not (file.exists() or folder.exists()):
@@ -604,7 +589,12 @@ class Notebook(ConnectorMixin, SignalEmitter):
 				pass # renaming on case-insensitive filesystem
 			elif newfile.exists() or newfolder.exists():
 				raise PageExistsError(newpath)
-		elif newfile.exists() or newfolder.exists():
+		elif newfile.exists():
+			if self.layout.is_source_file(newfile):
+				raise PageExistsError(newpath)
+			else:
+				raise PageNotAvailableError(newpath, newfile)
+		elif newfolder.exists():
 			raise PageExistsError(newpath)
 
 		# First move the dir - if it fails due to some file being locked
@@ -672,11 +662,11 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		def replacefunc(elt):
 			text = elt.attrib['href']
 			if link_type(text) != 'page':
-				raise zim.formats.VisitorSkip
+				return elt
 
 			href = HRef.new_from_wiki_link(text)
 			if href.rel == HREF_REL_RELATIVE:
-				raise zim.formats.VisitorSkip
+				pass
 			elif href.rel == HREF_REL_ABSOLUTE:
 				oldtarget = self.pages.resolve_link(page, href)
 				if oldtarget == oldroot:
@@ -684,8 +674,6 @@ class Notebook(ConnectorMixin, SignalEmitter):
 				elif oldtarget.ischild(oldroot):
 					newtarget = newroot + oldtarget.relname(oldroot)
 					return self._update_link_tag(elt, page, newtarget, href)
-				else:
-					raise zim.formats.VisitorSkip
 			else:
 				assert href.rel == HREF_REL_FLOATING
 				newtarget = self.pages.resolve_link(page, href)
@@ -693,21 +681,21 @@ class Notebook(ConnectorMixin, SignalEmitter):
 
 				if oldtarget == oldroot:
 					return self._update_link_tag(elt, page, newroot, href)
-				elif oldtarget.ischild(oldroot):
+				elif oldtarget.ischild(oldroot) and href.names:  # make sure href has parts
 					oldanchor = self.pages.resolve_link(oldpath, HRef(HREF_REL_FLOATING, href.parts()[0]))
 					if oldanchor.ischild(oldroot):
-						raise zim.formats.VisitorSkip # oldtarget cannot be trusted
+						pass # oldtarget cannot be trusted
 					else:
 						newtarget = newroot + oldtarget.relname(oldroot)
 						return self._update_link_tag(elt, page, newtarget, href)
 				elif newtarget != oldtarget:
 					# Redirect back to old target
 					return self._update_link_tag(elt, page, oldtarget, href)
-				else:
-					raise zim.formats.VisitorSkip
 
-		tree.replace(zim.formats.LINK, replacefunc)
-		page.set_parsetree(tree)
+			return elt
+
+		newtree = tree.substitute_elements((zim.formats.LINK,), replacefunc)
+		page.set_parsetree(newtree)
 		self.store_page(page)
 
 	def _update_links_to_moved_page(self, oldroot, newroot):
@@ -749,7 +737,7 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		def replacefunc(elt):
 			text = elt.attrib['href']
 			if link_type(text) != 'page':
-				raise zim.formats.VisitorSkip
+				return elt
 
 			href = HRef.new_from_wiki_link(text)
 			target = self.pages.resolve_link(page, href)
@@ -760,12 +748,16 @@ class Notebook(ConnectorMixin, SignalEmitter):
 				newtarget = newroot.child(target.relname(oldroot))
 				return self._update_link_tag(elt, page, newtarget, href)
 
-			elif href.rel == HREF_REL_FLOATING \
+			elif href.rel == HREF_REL_FLOATING and href.names \
 			and natural_sort_key(href.parts()[0]) == natural_sort_key(oldroot.basename) \
 			and page.ischild(oldroot.parent):
-				targetrecord = self.pages.lookup_by_pagename(target)
+				try:
+					targetrecord = self.pages.lookup_by_pagename(target)
+				except IndexNotFoundError:
+					targetrecord = None # technically this is a bug, but let's be robust
+
 				if not target.ischild(oldroot.parent) \
-				or not targetrecord.exists():
+				or targetrecord is None or not targetrecord.exists():
 					# An link that was anchored to the moved page,
 					# but now resolves somewhere higher in the tree
 					# Or a link that no longer resolves
@@ -775,74 +767,35 @@ class Notebook(ConnectorMixin, SignalEmitter):
 						mynewroot = newroot.child(':'.join(href.parts()[1:]))
 						return self._update_link_tag(elt, page, mynewroot, href)
 
-			raise zim.formats.VisitorSkip
+			return elt
 
-		tree.replace(zim.formats.LINK, replacefunc)
-		page.set_parsetree(tree)
+		newtree = tree.substitute_elements((zim.formats.LINK,), replacefunc)
+		page.set_parsetree(newtree)
 		self.store_page(page)
 
 	def _update_link_tag(self, elt, source, target, oldhref):
 		if oldhref.rel == HREF_REL_ABSOLUTE: # prefer to keep absolute links
 			newhref = HRef(HREF_REL_ABSOLUTE, target.name)
+		elif source == target and oldhref.anchor:
+			newhref = HRef(HREF_REL_FLOATING, '', oldhref.anchor)
 		else:
 			newhref = self.pages.create_link(source, target)
 
-		text = newhref.to_wiki_link()
-		if elt.gettext() == elt.get('href'):
-			elt[:] = [text]
-		elt.set('href', text)
+		newhref.anchor = oldhref.anchor
+
+		link = newhref.to_wiki_link()
+
+		from zim.formats import TEXT
+		if elt.content == [(TEXT, elt.attrib['href'])]:
+			elt.content[:] = [(TEXT, link)]
+		elif elt.content == [(TEXT, oldhref.short_name())]:
+			# Related to 'short_links' but not checking the property here.
+			elt.content[:] = [(TEXT, newhref.short_name())]  # 'Journal:2020:01:20' -> '20'
+
+		elt.attrib['href'] = link
+
 		return elt
 
-	def rename_page(self, path, newbasename, update_heading=True, update_links=True):
-		'''Rename page to a page in the same namespace but with a new
-		basename.
-
-		This is similar to moving within the same namespace, but
-		conceptually different in the user interface. Internally
-		L{move_page()} is used here as well.
-
-		@param path: a L{Path} object for the old/current page name
-		@param newbasename: new name as string
-		@param update_heading: if C{True} the first heading in the
-		page will be updated to the new name
-		@param update_links: if C{True} all links B{from} and B{to} this
-		page and any of it's children will be updated to reflect the
-		new page name
-
-		@emits: move-page before the move
-		@emits: moved-page after successfull move
-		'''
-		newbasename = Path.makeValidPageName(newbasename)
-		newpath = Path(path.namespace + ':' + newbasename)
-
-		for p in self.rename_page_iter(path, newbasename, update_heading, update_links):
-			pass
-
-		return newpath
-
-	@assert_index_uptodate
-	@notebook_state
-	def rename_page_iter(self, path, newbasename, update_heading=True, update_links=True):
-		'''Like L{rename_page()} but yields pages that are being updated
-		if C{update_links} is C{True}
-		'''
-		logger.debug('Rename %s to "%s" (%s, %s)',
-			path, newbasename, update_heading, update_links)
-
-		newbasename = Path.makeValidPageName(newbasename)
-		newpath = Path(path.namespace + ':' + newbasename)
-
-		for p in self.move_page_iter(path, newpath, update_links):
-			yield p
-
-		if update_heading:
-			page = self.get_page(newpath)
-			tree = page.get_parsetree()
-			if not tree is None:
-				tree.set_heading(newbasename)
-				page.set_parsetree(tree)
-				self.store_page(page)
-
 	@assert_index_uptodate
 	@notebook_state
 	def delete_page(self, path, update_links=True):
@@ -968,7 +921,7 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		return re
 
 	def _deleted_page(self, path, update_links):
-		self.flush_page_cache(path)
+		self._reload_pages_in_cache(path)
 		path = Path(path.name)
 
 		if update_links:
@@ -1000,19 +953,19 @@ class Notebook(ConnectorMixin, SignalEmitter):
 			href = elt.attrib['href']
 			type = link_type(href)
 			if type != 'page':
-				raise zim.formats.VisitorSkip
+				return elt
 
 			hrefpath = self.pages.lookup_from_user_input(href, page)
 			#~ print('LINK', hrefpath)
 			if hrefpath == path \
 			or hrefpath.ischild(path):
 				# Replace the link by it's text
-				return zim.formats.DocumentFragment(*elt)
+				return elt.content
 			else:
-				raise zim.formats.VisitorSkip
+				return elt
 
-		tree.replace(zim.formats.LINK, replacefunc)
-		page.set_parsetree(tree)
+		newtree = tree.substitute_elements((zim.formats.LINK,), replacefunc)
+		page.set_parsetree(newtree)
 
 	def resolve_file(self, filename, path=None):
 		'''Resolve a file or directory path relative to a page or
@@ -1036,32 +989,55 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		the I{attachment folder} of that page, otherwise they are
 		resolved relative to the I{notebook folder} - if any.
 
+		Paths ending with a "/" or "\" are considered folders.
+
 		The file is resolved purely based on the path, it does not have
-		to exist at all.
+		to exist at all. However if a folder of the name exists a L{Folder}
+		object is returned instead of a file.
 
 		@param filename: the (relative) file path or uri as string
 		@param path: a L{Path} object for the page
-		@returns: a L{File} object.
+		@returns: a L{File} or L{Folder} object.
 		'''
-		assert isinstance(filename, str)
+		assert isinstance(filename, str) and filename
+		try:
+			file = self._resolve_abs_file(filename)
+		except:
+			logger.exception('Could not resolve filename as absolute path: %s', filename)
+			file = None
+
+		if file is None:
+			if path:
+				folder = self.get_attachments_dir(path)
+			else:
+				folder = self.layout.root
+
+			file = LocalFile(folder.get_abspath(filename))
+
+		myfolder = LocalFolder(file)
+		if filename[-1] in ('/', '\\') or myfolder.exists():
+			return myfolder
+		else:
+			return file
+
+	def _resolve_abs_file(self, filename):
+		# Code shared between notebook & export linker
 		filename = filename.replace('\\', '/')
 		if filename.startswith('~') or filename.startswith('file:/'):
-			return File(filename)
+			file = LocalFile(filename) # Note: can raise for non-local file URI
 		elif filename.startswith('/'):
-			dir = self.document_root or Dir('/')
-			return dir.file(filename)
+			if self.document_root:
+				file = self.document_root.file(filename)
+			else:
+				file = LocalFile(filename)
 		elif is_win32_path_re.match(filename):
 			if not filename.startswith('/'):
-				filename = '/' + filename
-				# make absolute on Unix
-			return File(filename)
+				filename = '/' + filename # make absolute on Unix
+			file = LocalFile(filename)
 		else:
-			if path:
-				dir = self.get_attachments_dir(path)
-				return File((dir.path, filename)) # XXX LocalDir --> File -- will need get_abspath to resolve
-			else:
-				dir = Dir(self.layout.root.path) # XXX
-				return File((dir, filename))
+			file = None
+
+		return file
 
 	def relative_filepath(self, file, path=None):
 		'''Get a file path relative to the notebook or page
@@ -1090,21 +1066,24 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		@returns: relative file path as string, or C{None} when no
 		relative path was found
 		'''
-		from zim.newfs import LocalFile, LocalFolder
-		file = LocalFile(file.path) # XXX
+		file = adapt_from_oldfs(file)
+		if not file.islocal:
+			return None
+
 		notebook_root = self.layout.root
 		document_root = LocalFolder(self.document_root.path) if self.document_root else None# XXX
 
 		rootdir = '/'
 		mydir = '.' + SEP
 		updir = '..' + SEP
+		postfix = SEP if isinstance(file, Folder) else ''
 
 		# Look within the notebook
 		if path:
 			attachments_dir = self.get_attachments_dir(path)
 
 			if file.ischild(attachments_dir):
-				return mydir + file.relpath(attachments_dir)
+				return mydir + file.relpath(attachments_dir) + postfix
 			elif document_root and notebook_root \
 			and document_root.ischild(notebook_root) \
 			and file.ischild(document_root) \
@@ -1112,48 +1091,49 @@ class Notebook(ConnectorMixin, SignalEmitter):
 				# special case when document root is below notebook root
 				# the case where document_root == attachment_folder is
 				# already caught by above if clause
-				return rootdir + file.relpath(document_root)
+				return rootdir + file.relpath(document_root) + postfix
 			elif notebook_root \
 			and file.ischild(notebook_root) \
 			and attachments_dir.ischild(notebook_root):
 				parent = file.commonparent(attachments_dir)
 				uppath = attachments_dir.relpath(parent)
 				downpath = file.relpath(parent)
-				up = 1 + uppath.count('/')
-				return updir * up + downpath
+				up = 1 + uppath.replace('\\', '/').count('/')
+				return updir * up + downpath + postfix
 		else:
 			if document_root and notebook_root \
 			and document_root.ischild(notebook_root) \
 			and file.ischild(document_root):
 				# special case when document root is below notebook root
-				return rootdir + file.relpath(document_root)
+				return rootdir + file.relpath(document_root) + postfix
 			elif notebook_root and file.ischild(notebook_root):
-				return mydir + file.relpath(notebook_root)
+				return mydir + file.relpath(notebook_root) + postfix
 
 		# If that fails look for global folders
 		if document_root and file.ischild(document_root):
-			return rootdir + file.relpath(document_root)
+			return rootdir + file.relpath(document_root) + postfix
 
 		# Finally check HOME or give up
-		path = file.userpath
+		path = file.userpath + postfix
 		return path if path.startswith('~') else None
 
 	def get_attachments_dir(self, path):
 		'''Get the X{attachment folder} for a specific page
 
 		@param path: a L{Path} object
-		@returns: a L{Dir} object or C{None}
+		@returns: a L{Folder} object or C{None}
 
-		Always returns a Dir object when the page can have an attachment
+		Always returns an object when the page can have an attachment
 		folder, even when the folder does not (yet) exist. However when
 		C{None} is returned the store implementation does not support
 		an attachments folder for this page.
 		'''
 		return self.layout.get_attachments_folder(path)
 
-	def get_template(self, path):
+	def get_template(self, path, context=None):
 		'''Get a template for the intial text on new pages
 		@param path: a L{Path} object
+		@param context: optional dict with additional context parameters
 		@returns: a L{ParseTree} object
 		'''
 		# FIXME hardcoded that template must be wiki format
@@ -1161,7 +1141,7 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		template = self.get_page_template_name(path)
 		logger.debug('Got page template \'%s\' for %s', template, path)
 		template = zim.templates.get_template('wiki', template)
-		return self.eval_new_page_template(path, template)
+		return self.eval_new_page_template(path, template, context)
 
 	def get_page_template_name(self, path=None):
 		'''Returns the name of the template to use for a new page.
@@ -1169,9 +1149,9 @@ class Notebook(ConnectorMixin, SignalEmitter):
 		'''
 		return self.emit_return_first('get-page-template', path or Path(':')) or 'Default'
 
-	def eval_new_page_template(self, path, template):
+	def eval_new_page_template(self, path, template, context=None):
 		lines = []
-		context = {
+		mycontext = {
 			'page': {
 				'name': path.name,
 				'basename': path.basename,
@@ -1179,8 +1159,10 @@ class Notebook(ConnectorMixin, SignalEmitter):
 				'namespace': path.namespace, # backward compat
 			}
 		}
+		if context:
+			mycontext.update(context)
 		self.emit('init-page-template', path, template) # plugin hook
-		template.process(lines, context)
+		template.process(lines, mycontext)
 
 		parser = zim.formats.get_parser('wiki')
 		return parser.parse(lines)
