@@ -7,15 +7,13 @@ from zim.plugins import PluginClass
 from zim.plugins.base.imagegenerator import \
 	ImageGeneratorClass, BackwardImageGeneratorObjectType
 
-from zim.fs import File, TmpFile
+from zim.newfs import LocalFile, TmpFile
 from zim.templates import get_template
 from zim.applications import Application, ApplicationError
 
-
 # TODO put these commands in preferences
-latexcmd = ('latex', '-no-shell-escape', '-halt-on-error')
-dvipngcmd = ('dvipng', '-q', '-bg', 'Transparent', '-T', 'tight', '-o')
-
+latexcmd = 'latex'
+dvipngcmd = 'dvipng'
 
 class InsertEquationPlugin(PluginClass):
 
@@ -32,8 +30,10 @@ This is a core plugin shipping with zim.
 
 	plugin_preferences = (
 		# key, type, label, default
-		('dark_mode', 'bool', _('Use font color for dark theme'), False),
-        )
+		('dark_mode', 'bool', _('Use font color for dark theme'), False), # T: plugin preference
+		('font_size', 'int', _('Font size'), 12, (6, 24)), # T: plugin preference
+		('output_dpi', 'choice', _('Equation image DPI'), "96", ("96","120","150","200","300","400","600")), # T: plugin preference
+    )
 
 	@classmethod
 	def check_dependencies(klass):
@@ -49,7 +49,7 @@ class BackwardEquationImageObjectType(BackwardImageGeneratorObjectType):
 	label = _('Equation') # T: menu item
 	syntax = 'latex'
 	scriptname = 'equation.tex'
-	imagefile_extension = '.png'
+	widget_style = 'inline'
 
 	def format_latex(self, dumper, attrib, data):
 		if attrib['src'] and not attrib['src'] == '_new_':
@@ -64,6 +64,8 @@ class BackwardEquationImageObjectType(BackwardImageGeneratorObjectType):
 
 class EquationGenerator(ImageGeneratorClass):
 
+	imagefile_extension = '.png'
+
 	def __init__(self, plugin, notebook, page):
 		ImageGeneratorClass.__init__(self, plugin, notebook, page)
 		self.preferences = plugin.preferences
@@ -83,27 +85,28 @@ class EquationGenerator(ImageGeneratorClass):
 		lines = []
 		self.template.process(lines, {
 			'equation': text,
+			'font_size': self.preferences['font_size'],
 			'dark_mode': self.preferences['dark_mode']
 		})
 		self.texfile.writelines(lines)
 		#~ print('>>>%s<<<' % self.texfile.read())
 
 		# Call latex
-		logfile = File(self.texfile.path[:-4] + '.log') # len('.tex') == 4
+		logfile = LocalFile(self.texfile.path[:-4] + '.log') # len('.tex') == 4
 		#~ print(">>>", self.texfile, logfile)
 		try:
-			latex = Application(latexcmd)
-			latex.run((self.texfile.basename,), cwd=self.texfile.dir)
+			latex = Application('%s -no-shell-escape -halt-on-error' % (latexcmd))
+			latex.run((self.texfile.basename,), cwd=self.texfile.parent())
 		except ApplicationError:
 			# log should have details of failure
 			return None, logfile
 
 		# Call dvipng
-		dvifile = File(self.texfile.path[:-4] + '.dvi') # len('.tex') == 4
-		pngfile = File(self.texfile.path[:-4] + '.png') # len('.tex') == 4
-		dvipng = Application(dvipngcmd)
+		dvifile = LocalFile(self.texfile.path[:-4] + '.dvi') # len('.tex') == 4
+		pngfile = LocalFile(self.texfile.path[:-4] + '.png') # len('.tex') == 4
+		dvipng = Application('%s -q -bg Transparent -T tight -D %s -o' % (dvipngcmd,self.preferences['output_dpi']))
 		dvipng.run((pngfile, dvifile)) # output, input
-			# No try .. except here - should never fail
+		# No try .. except here - should never fail
 		# TODO dvipng can start processing before latex finished - can we win speed there ?
 
 		return pngfile, logfile
@@ -111,4 +114,4 @@ class EquationGenerator(ImageGeneratorClass):
 	def cleanup(self):
 		path = self.texfile.path
 		for path in glob.glob(path[:-4] + '.*'):
-			File(path).remove()
+			LocalFile(path).remove()
